package geom

import (
	"fmt"
	"math"
	"testing"
)

func TestAdd(t *testing.T) {
	p := Point{1, 2}
	q := Point{2, 3}
	result := p.Add(q)
	if result.X != 3 || result.Y != 5 {
		t.Errorf("Expected (3,5) but result is (%f, %f)", result.X, result.Y)
	}
}

var addTestTable = []struct {
	p        Point
	q        Point
	expected Point
}{
	{p: Point{1, 2}, q: Point{2, 3}, expected: Point{3, 5}},
	{p: Point{-1, -2}, q: Point{-2, -3}, expected: Point{-3, -5}},
	{p: Point{1, 2}, q: Point{-2, -3}, expected: Point{-1, -1}},
}

func TestAddTable(t *testing.T) {
	for _, test := range addTestTable {

		testname := fmt.Sprintf("%v,%v", test.p, test.q)
		t.Run(testname, func(t *testing.T) {
			result := test.p.Add(test.q)
			if result.X != test.expected.X || result.Y != test.expected.Y {
				t.Errorf("Expected (%f,%f) but result is (%f, %f)", test.expected.X, test.expected.Y, result.X, result.Y)
			}
		})
	}
}

func TestDistance(t *testing.T) {
	p := Point{1, 2}
	q := Point{2, 3}
	dist := p.Distance(q)
	if dist != math.Sqrt(2) {
		t.Errorf("Expected distance sqrt(2) but result is %f", dist)
	}
}
